==> raspberry-client-9.3.1.tgz: package/migrate/9.3.0_pooliot-client.sh <==
#!/bin/sh


replaceText() {
    var1=$(escapeVariable "$1")
    var2=$(escapeVariable "$2")
    sudo sed -i "s/$var1/$var2/g" $3
}

. /etc/os-release


# UPGRADE NODE


sudo rm -r  /etc/apt/sources.list.d/nodesource.list
curl -sL https://deb.nodesource.com/setup_8.x | sudo -E bash -
sudo apt-get install -y nodejs

if [ $ID = 'raspbian' ]; then
  sudo ln -s /usr/bin/chromium-browser /usr/bin/chromium
fi


# NEW CLIENT pooliot-client


sudo npm install -g pooliot-client


# LXDE


sudo apt-get install -y lxde-core lxappearance lightdm
sudo systemctl set-default graphical.target

sudo cp /etc/xdg/lxsession/LXDE/autostart /etc/xdg/lxsession/LXDE/autostart.backup
echo '#@lxpanel --profile LXDE
#@pcmanfm --desktop --profile LXDE
#@xscreensaver -no-splash
pooliot-client display lxde-started' | sudo tee /etc/xdg/lxsession/LXDE/autostart

if [ -f /usr/bin/chromium-browser ]; then
  ln -s /usr/bin/chromium-browser /usr/bin/chromium
fi

POOLIOT_USER=pi
BASEDIR=$(dirname "$0")

sudo mkdir -p "/home/$POOLIOT_USER/.config/openbox/" "/home/$POOLIOT_USER/.config/lxsession/LXDE/"

## lxsession/LXDE/autostart
if [ ! -f /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart.backup ]; then
  sudo cp /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart.backup
fi

echo '#@lxpanel --profile LXDE
#@pcmanfm --desktop --profile LXDE
#@xscreensaver -no-splash
pooliot-client display lxde-started' | sudo tee /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart

## openbox/lxde-rc.xml

if [ ! -f /home/$POOLIOT_USER/.config/openbox/lxde-rc.xml.backup ]; then
  cp /home/$POOLIOT_USER/.config/openbox/lxde-rc.xml /home/$POOLIOT_USER/.config/openbox/lxde-rc.xml.backup || echo
fi

cat "$BASEDIR/../scripts/install/display/lxde-rc.xml" | sudo tee "/home/$POOLIOT_USER/.config/openbox/lxde-rc.xml"

## chown
sudo chown -R $POOLIOT_USER:$POOLIOT_USER "/home/$POOLIOT_USER/.config/openbox/" "/home/$POOLIOT_USER/.config/lxsession/"


# CLEAN

sudo npm uninstall -g raspberry-client

# INSTALL

echo '' | sudo tee /etc/xdg/openbox/autostart

sudo rm /etc/supervisor/conf.d/openbox.conf
sudo supervisorctl update


systemctl disable raspberry-client

mv /etc/systemd/system/raspberry-client.service /etc/systemd/system/pooliot-client.service
replaceText "raspberry-client/lib-node6" "raspberry-client/lib-node8" /etc/systemd/system/pooliot-client.service
replaceText "Environment=USER_ID=" "Environment=TOKEN=" /etc/systemd/system/pooliot-client.service
replaceText "SyslogIdentifier=raspberry-client" "SyslogIdentifier=pooliot-client" /etc/systemd/system/pooliot-client.service

systemctl enable pooliot-client
systemctl start pooliot-client

==> raspberry-client-9.3.5.tgz: package/migrate/9.3.0_pooliot-client.sh <==
#!/bin/sh

escapeVariable() {
    echo "$(echo "$1" | sed -e 's/[\/()&]/\\&/g')"
}

replaceText() {
    var1=$(escapeVariable "$1")
    var2=$(escapeVariable "$2")
    sudo sed -i "s/$var1/$var2/g" $3
}

. /etc/os-release


# UPGRADE NODE


sudo rm -r  /etc/apt/sources.list.d/nodesource.list
curl -sL https://deb.nodesource.com/setup_8.x | sudo -E bash -
sudo apt-get install -y nodejs

if [ $ID = 'raspbian' ]; then
  sudo ln -s /usr/bin/chromium-browser /usr/bin/chromium
fi


# NEW CLIENT pooliot-client


sudo npm install -g pooliot-client


# cec-utils


sudo apt-get install -y cec-utils


# LXDE

sudo apt-get install -y lxde-core lxappearance lightdm
sudo systemctl set-default graphical.target

sudo cp /etc/xdg/lxsession/LXDE/autostart /etc/xdg/lxsession/LXDE/autostart.backup
echo '#@lxpanel --profile LXDE
#@pcmanfm --desktop --profile LXDE
#@xscreensaver -no-splash
pooliot-client display lxde-started' | sudo tee /etc/xdg/lxsession/LXDE/autostart

if [ -f /usr/bin/chromium-browser ]; then
  ln -s /usr/bin/chromium-browser /usr/bin/chromium
fi

POOLIOT_USER=pi
BASEDIR=$(dirname "$0")

sudo mkdir -p "/home/$POOLIOT_USER/.config/openbox/" "/home/$POOLIOT_USER/.config/lxsession/LXDE/"

## lxsession/LXDE/autostart
if [ ! -f /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart.backup ]; then
  sudo cp /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart.backup
fi

echo '#@lxpanel --profile LXDE
#@pcmanfm --desktop --profile LXDE
@xscreensaver -no-splash
pooliot-client display lxde-started' | sudo tee /home/$POOLIOT_USER/.config/lxsession/LXDE/autostart

## openbox/lxde-rc.xml

if [ ! -f /home/$POOLIOT_USER/.config/openbox/lxde-rc.xml.backup ]; then
  cp /home/$POOLIOT_USER/.config/openbox/lxde-rc.xml /home/$POOLIOT_USER/.config/openbox/lxde-rc.xml.backup || echo
fi

cat "$BASEDIR/../scripts/install/display/lxde-rc.xml" | sudo tee "/home/$POOLIOT_USER/.config/openbox/lxde-rc.xml"

## chown
sudo chown -R $POOLIOT_USER:$POOLIOT_USER "/home/$POOLIOT_USER/.config/openbox/" "/home/$POOLIOT_USER/.config/lxsession/"


# CLEAN

sudo npm uninstall -g raspberry-client

# INSTALL

echo '' | sudo tee /etc/xdg/openbox/autostart

sudo rm /etc/supervisor/conf.d/openbox.conf
sudo supervisorctl update


systemctl disable raspberry-client

mv /etc/systemd/system/raspberry-client.service /etc/systemd/system/pooliot-client.service
replaceText "raspberry-client/lib-node6" "pooliot-client/lib-node8" /etc/systemd/system/pooliot-client.service
replaceText "Environment=USER_ID=" "Environment=TOKEN=" /etc/systemd/system/pooliot-client.service
replaceText "SyslogIdentifier=raspberry-client" "SyslogIdentifier=pooliot-client" /etc/systemd/system/pooliot-client.service

systemctl daemon-reload
systemctl enable pooliot-client

reboot
